changeset 20385:e1ea41eba8be

(sh-mode): Set `comment-start-skip' always.
author Dave Love <fx@gnu.org>
date Sun, 30 Nov 1997 12:21:42 +0000
parents 931b472be076
children 25ca60b3ca09
files lisp/progmodes/sh-script.el
diffstat 1 files changed, 6 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/progmodes/sh-script.el	Sun Nov 30 12:20:49 1997 +0000
+++ b/lisp/progmodes/sh-script.el	Sun Nov 30 12:21:42 1997 +0000
@@ -731,9 +731,12 @@
 	       (match-string 2)))))
     (if interpreter
 	(sh-set-shell interpreter nil nil)
-      ;; If we don't know the shell for this file,
-      ;; set the syntax table anyway, for the user's normal choice of shell.
-      (set-syntax-table (sh-feature sh-mode-syntax-table))))
+      (progn
+        ;; If we don't know the shell for this file, set the syntax
+        ;; table anyway, for the user's normal choice of shell.
+        (set-syntax-table (sh-feature sh-mode-syntax-table))
+        ;; And avoid indent-new-comment-line (at least) losing.
+        (setq comment-start-skip "#+[\t ]*"))))
   (run-hooks 'sh-mode-hook))
 ;;;###autoload
 (defalias 'shell-script-mode 'sh-mode)